@@ -26,7 +26,7 @@ from airbyte_api.models import JobCreateRequest, JobStatusEnum, JobTypeEnum, Sch
 from requests import Session
 
 from airflow.exceptions import AirflowException
-from airflow.providers.airbyte.version_compat import BaseHook
+from airflow.providers.common.compat.sdk import BaseHook
 
 T = TypeVar("T", bound=Any)
 
@@ -59,6 +59,13 @@ class AirbyteHook(BaseHook):
     def get_conn_params(self, conn_id: str) -> Any:
         conn = self.get_connection(conn_id)
 
+        # Intentionally left the password out, you can modify the log to print it out if you are doing testing.
+        self.log.debug(
+            "Connection attributes are: host - %s, url - %s, description - %s",
+            conn.host,
+            conn.schema,
+            conn.description,
+        )
         conn_params: dict = {}
         conn_params["host"] = conn.host
         conn_params["client_id"] = conn.login
@@ -78,6 +85,7 @@ class AirbyteHook(BaseHook):
 
         client = None
         if self.conn["proxies"]:
+            self.log.debug("Creating client proxy...")
             client = Session()
             client.proxies = self.conn["proxies"]
 
@@ -111,6 +119,7 @@ class AirbyteHook(BaseHook):
                     job_id=job_id,
                 )
             )
+            self.log.debug("Job details are: %s", get_job_res.job_response)
             return get_job_res.job_response
         except Exception as e:
             raise AirflowException(e)
@@ -138,12 +147,14 @@ class AirbyteHook(BaseHook):
         start = time.monotonic()
         while True:
             if timeout and start + timeout < time.monotonic():
+                self.log.debug("Canceling job...")
                 self.cancel_job(job_id=(int(job_id)))
                 raise AirflowException(f"Timeout: Airbyte job {job_id} is not ready after {timeout}s")
             time.sleep(wait_seconds)
             try:
                 job = self.get_job_details(job_id=(int(job_id)))
                 state = job.status
+                self.log.debug("Job State: %s. Job Details: %s", state, job)
 
             except AirflowException as err:
                 self.log.info("Retrying. Airbyte API returned server error when waiting for job: %s", err)
@@ -161,12 +172,14 @@ class AirbyteHook(BaseHook):
 
     def submit_sync_connection(self, connection_id: str) -> Any:
         try:
+            self.log.debug("Creating job request..")
             res = self.airbyte_api.jobs.create_job(
                 request=JobCreateRequest(
                     connection_id=connection_id,
                     job_type=JobTypeEnum.SYNC,
                 )
             )
+            self.log.debug("Job request successful, response: %s", res.job_response)
             return res.job_response
         except Exception as e:
             raise AirflowException(e)
@@ -191,6 +204,7 @@ class AirbyteHook(BaseHook):
         """Tests the Airbyte connection by hitting the health API."""
         try:
             health_check = self.airbyte_api.health.get_health_check()
+            self.log.debug("Health check details: %s", health_check)
             if health_check.status_code == 200:
                 return True, "Connection successfully tested"
             return False, str(health_check.raw_response)
